API
====

Getting resources records

===================== ========================================
Record types          Description
===================== ========================================
api.A.get()           Get Host Address
api.AAAA.get()        Get IPv6 Host Address
api.CERT.get()        Get Certificate
api.CNAME.get()       Get Canonical Name
api.DHCID.get()       Get DHCP Identifier
api.DLV.get()         Get DNSSEC Lookaside Validation record
api.DNAME.get()       Get Delegation name
api.DNSKEY.get()      Get DNS Key record
api.DS.get()          Get Delegation Signer
api.HINFO.get()       Get Host Information
api.HIP.get()         Get Host Identity Protocol
api.IPSECKEY.get()    Get IPSec Key
api.KX.get()          Get Key eXchanger record
api.LOC.get()         Get Location record
api.MX.get()          Get Mail Exchange record
api.NAPTR.get()       Get Name Authority Pointer
api.NS.get()          Get Name Servers
api.NSEC.get()        Get Next-Secure record
api.NSEC3.get()       Get NSEC record version 3
api.NSEC3PARAM.get()  Get NSEC3 parameters
api.OPT.get()         Get Option record
api.PTR.get()         Get Pointer record
api.RRSIG.get()       Get Resource Records Signature
api.SOA.get()         Get Start of Authority
api.SPF.get()         Get Sender Policy Framework
api.SRV.get()         Get Service Locator
api.SSHFP.get()       Get SSH Public Key Fingerprint
api.TA.get()          Get DNSSEC Trust Authorities
api.TALINK.get()      Get Trust Anchor LINK
api.TLSA.get()        Get TLSA records
api.TXT.get()         Get Text record
===================== ========================================
